@@ -8,6 +8,12 @@ test_that('scto_read dataset ok', {
   expect_data_table(d)
 })
 
+test_that('scto_read dataset drop empties', {
+  skip_on_cran()
+  d = scto_read(auth, 'enumerators', drop_empty_cols = TRUE)
+  expect_data_table(d)
+})
+
 test_that('scto_read dataset not ok', {
   skip_on_cran()
   expect_error(scto_read(auth, 'flux_capacitors'))
@@ -27,13 +33,13 @@ test_that('scto_read form not ok', {
 test_that('scto_read form encrypted no key', {
   skip_on_cran()
   d = scto_read(auth, 'hh_example_encrypted')
-  expect_data_table(d, ncols = 7L)
+  expect_data_table(d, ncols = 10L)
 })
 
 test_that('scto_read form encrypted key', {
   skip_on_cran()
   d = scto_read(auth, 'hh_example_encrypted', private_key = private_key)
-  expect_data_table(d, ncols = 20L)
+  expect_data_table(d, ncols = 21L)
 })
 
 test_that('scto_read not simplify', {
